#
# spec file for package python-GridDataFormats
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python36 1
Name:           python-GridDataFormats
Version:        1.0.2
Release:        1.2
Summary:        Python Tools for Reading and writing of data on regular grids
License:        GPL-3.0-only
URL:            https://github.com/MDAnalysis/GridDataFormats/
Source0:        https://files.pythonhosted.org/packages/source/G/GridDataFormats/GridDataFormats-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-mrcfile
Requires:       python-numpy >= 1.0.3
Requires:       python-scipy
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module mrcfile}
BuildRequires:  %{python_module numpy >= 1.0.3}
BuildRequires:  %{python_module paramiko}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
The *gridDataFormats* package provides classes to unify reading and
writing n-dimensional datasets. One can read grid data from files,
make them available as a :class:`Grid` object, and allows one to
write out the data again.

%prep
%autosetup -p1 -n GridDataFormats-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS CHANGELOG README.rst
%license COPYING*
%{python_sitelib}/gridData
%{python_sitelib}/GridDataFormats-%{version}-py*.egg-info

%changelog
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Python 3.12 is now supported (PR #128)
  * Use new MDAnalysis docs theme (PR #127)
  * updated versioneer to be able to run under Python 3.12
  * replaced deprecated pkg_resources in tests with importlib
* Tue May  2 2023 pgajdos@suse.com
- version update to 1.0.1
  1.0.1
  - ----
  Changes
  * Deployment is now automatically done using github actions.
  Fixes
  * Version 1.0.0 would allow for installations to be made with python versions
    < 3.8, resulting in incorrect builds. The setup configuration has now been
    altered to avoid this (Issue #112)
  1.0.0
  - ----
  Changes
  * API-stable release
  * deprecated and buggy CCP4 module was removed (#107, #50)
  * gridDataFormats now follows NEP29 (#102)
  * removed support for Python 2.7 and Python <3.8 (#102)
  0.7.0
  - ----
  Changes
  * Python 3.10 is supported (issue #101)
  Enhancements
  * use mrcfile library to parse MRC files (including CCP4) using the
    new mrc.MRC class (issue #83)
  Fixes
  * The new mrc module correctly reorients the coordinate system based
    on mapc, mapr, maps and correctly calculates the origin (issue #76)
  * documented Grid attributes, including axis convention (issue #69)
  Deprecations
  * The CCP4 module (replaced by mrc) will be removed in 1.0.0
  0.6.0
  - ----
  Changes
  * macOS and Windows are also tested (min and max supported Python, #97)
  Enhancements
  * Allow parsing/writing gzipped DX files (PR #70, #99)
  * Update doc theme to use sphinx-rtd-theme (#80)
  * Delta of OpenDX writes 7 significant figures (#88)
  Fixes
  * fix initialization of mutable instance variable of Grid class (metadata dict) (#71)
  * fix multiple __init__ calls (#73)
  * interpolation behavior outside of the grid changed to default to a
    constant rather than the nearest value (#84)
  * corrected resampling behavior to not draw on values outside of the grid (#84)
* Tue Apr 20 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.0
  + Changes
  * supported/tested on Python 2.7, >=3.5 (official 3.4 support was
    dropped: it might still work but is not tested anymore)
  + Enhancements
  * Allow parsing DX files by NAMD's GridForces module (new typequote keyword)
  * New keyword argument ``Grid(grid=<file>, file_format=<str>)`` to set file format when
    reading from a file
  + Fixes
  * Allow parsing DX files by Pymol's buggy floating-point parser
  * Fixed loading of pickle files with .pkl suffix
  * Better input handling when constructing a Grid object
- Remove upstream-included no_float128.patch
* Tue May 15 2018 toddrme2178@gmail.com
- Add no_float128.patch
  Fixes tests
  See https://github.com/MDAnalysis/GridDataFormats/issues/44
  From https://github.com/MDAnalysis/GridDataFormats/pull/45/commits/069422d54344034b8f31bb19eee8a097b582c0e1
  Should be in next release
* Fri May 11 2018 toddrme2178@gmail.com
- Update to 0.4.0
  * Type of DX arrays is now set based on the numpy array dtype or can
    be manually set by the user to increase interoperability with
    tools such as PyMOL (issue #35)
* Mon May 15 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Fix source URL.
- Run unit tests.
* Thu Nov 17 2016 alinm.elena@gmail.com
- updated to version 0.3.3
  * removed SUMMARY.txt
* Wed Mar 12 2014 toddrme2178@gmail.com
- Update to 2.4
  * No upstream changelog
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 0.2.2:
  + Upstream provides no changelog
* Thu Jan 12 2012 saschpe@suse.de
- Package AUTHORS, COPYING, README
- Spec cleanup:
  + Removed %%clean section (sane default)
  + Simpler macros
  + No CFLAGS for Python-only package needed
* Wed Jan 11 2012 toddrme2178@gmail.com
- Cleaned up spec file
* Thu Sep  8 2011 alinm.elena@gmail.com
- initial commit
